@@ -1,15 +1,17 @@
 package Sah::Schema::negodd;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-08'; # DATE
+our $DATE = '2020-05-21'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.074'; # VERSION
+our $VERSION = '0.075'; # VERSION
 
 our $schema = ['negint', {
     summary => 'Negative odd number',
     div_by => 2,
     'div_by.op' => 'not',
     examples => [
+        {data=>0, valid=>0},
+        {data=>1, valid=>0},
         {data=>-1, valid=>1},
         {data=>-2, valid=>0},
     ],
@@ -30,7 +32,7 @@ Sah::Schema::negodd - Negative odd number
 
 =head1 VERSION
 
-This document describes version 0.074 of Sah::Schema::negodd (from Perl distribution Sah-Schemas-Int), released on 2020-05-08.
+This document describes version 0.075 of Sah::Schema::negodd (from Perl distribution Sah-Schemas-Int), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -95,6 +97,10 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
+ 0  # INVALID
+
+ 1  # INVALID
+
  -1  # valid
 
  -2  # INVALID
