@@ -1,15 +1,16 @@
 package Sah::Schema::poseven;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-08'; # DATE
+our $DATE = '2020-05-21'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.074'; # VERSION
+our $VERSION = '0.075'; # VERSION
 
 our $schema = ['posint', {
     summary => 'Positive even number',
     div_by => 2,
     examples => [
         {data=>2, valid=>1},
+        {data=>-2, valid=>0},
         {data=>1, valid=>0},
         {data=>0, valid=>0},
     ],
@@ -30,7 +31,7 @@ Sah::Schema::poseven - Positive even number
 
 =head1 VERSION
 
-This document describes version 0.074 of Sah::Schema::poseven (from Perl distribution Sah-Schemas-Int), released on 2020-05-08.
+This document describes version 0.075 of Sah::Schema::poseven (from Perl distribution Sah-Schemas-Int), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -97,6 +98,8 @@ Sample data:
 
  2  # valid
 
+ -2  # INVALID
+
  1  # INVALID
 
  0  # INVALID
