@@ -1,9 +1,9 @@
 package Sah::Schema::uint32;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-08'; # DATE
+our $DATE = '2020-05-21'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.074'; # VERSION
+our $VERSION = '0.075'; # VERSION
 
 our $schema = [int => {
     summary => '32-bit unsigned integer',
@@ -12,6 +12,8 @@ our $schema = [int => {
     examples => [
         {data=> 0, valid=>1},
         {data=>-1, valid=>0},
+        {data=>2**32-1, valid=>1},
+        {data=>2**32, valid=>0},
     ],
 }, {}];
 
@@ -30,7 +32,7 @@ Sah::Schema::uint32 - 32-bit unsigned integer
 
 =head1 VERSION
 
-This document describes version 0.074 of Sah::Schema::uint32 (from Perl distribution Sah-Schemas-Int), released on 2020-05-08.
+This document describes version 0.075 of Sah::Schema::uint32 (from Perl distribution Sah-Schemas-Int), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -99,6 +101,10 @@ Sample data:
 
  -1  # INVALID
 
+ 4294967295  # valid
+
+ 4294967296  # INVALID
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Int>.
